@@ -19,7 +19,7 @@ def transform_timeseries(
     Block that transforms the dataframe of a time series task to a convenient format for use in posterior phases like model training.
     
     The main transformations performed by this block are:
-      - Type casting (e.g. to numerical for `order_by` columns).
+      - Type casting (e.g. to numerical for `order_by` column).
       - Windowing functions for historical context based on `TimeseriesSettings.window` parameter.
       - Explicitly add target columns according to the `TimeseriesSettings.horizon` parameter.
       - Flag all rows that are "predictable" based on all `TimeseriesSettings`.
@@ -37,7 +37,7 @@ def transform_timeseries(
 
     tss = timeseries_settings
     gb_arr = tss.group_by if tss.group_by is not None else []
-    ob_arr = tss.order_by
+    oby = tss.order_by
     window = tss.window
 
     if tss.use_previous_target and target not in data.columns:
@@ -48,19 +48,23 @@ def transform_timeseries(
             raise Exception(f"Cannot transform. Missing values in historical column {hcol}.")
 
     # infer frequency with get_delta
-    oby_col = tss.order_by[0]
+    oby_col = tss.order_by
     groups = get_ts_groups(data, tss)
     if not ts_analysis:
-        _, _, freqs = get_delta(data, dtype_dict, groups, tss)
+        _, periods, freqs = get_delta(data, dtype_dict, groups, tss)
     else:
+        periods = ts_analysis['periods']
         freqs = ts_analysis['sample_freqs']
 
     # pass seconds to timestamps according to each group's inferred freq, and force this freq on index
     subsets = []
     for group in groups:
         if (tss.group_by and group != '__default') or not tss.group_by:
+            if periods[group] == 0:
+                raise Exception(
+                    f"Partition is not valid, faulty group {group}. Please make sure you group by a set of columns that ensures unique measurements for each grouping through time.")  # noqa
             idxs, subset = get_group_matches(data, group, tss.group_by)
-            if subset.size > 0:
+            if subset.shape[0] > 0:
                 index = pd.to_datetime(subset[oby_col], unit='s')
                 subset.index = pd.date_range(start=index.iloc[0], freq=freqs[group], periods=len(subset))
                 subset['__mdb_inferred_freq'] = subset.index.freq   # sets constant column because pd.concat forgets freq (see: https://github.com/pandas-dev/pandas/issues/3232)  # noqa
@@ -101,28 +105,25 @@ def transform_timeseries(
     original_df['original_index'] = original_index_list
 
     secondary_type_dict = {}
-    for col in ob_arr:
-        if dtype_dict[col] in (dtype.date, dtype.integer, dtype.float):
-            secondary_type_dict[col] = dtype_dict[col]
-
-    for oby in tss.order_by:
-        original_df[f'__mdb_original_{oby}'] = original_df[oby]
+    if dtype_dict[oby] in (dtype.date, dtype.integer, dtype.float):
+        secondary_type_dict[oby] = dtype_dict[oby]
 
+    original_df[f'__mdb_original_{oby}'] = original_df[oby]
     group_lengths = []
     if len(gb_arr) > 0:
         df_arr = []
         for _, df in original_df.groupby(gb_arr):
-            df_arr.append(df.sort_values(by=ob_arr))
+            df_arr.append(df.sort_values(by=oby))
             group_lengths.append(len(df))
     else:
-        df_arr = [original_df.sort_values(by=ob_arr)]
+        df_arr = [original_df.sort_values(by=oby)]
         group_lengths.append(len(original_df))
 
     n_groups = len(df_arr)
     for i, subdf in enumerate(df_arr):
         if '__mdb_forecast_offset' in subdf.columns and mode == 'predict':
             if infer_mode:
-                df_arr[i] = _ts_infer_next_row(subdf, ob_arr)
+                df_arr[i] = _ts_infer_next_row(subdf, oby)
                 make_preds = [False for _ in range(max(0, len(df_arr[i]) - 1))] + [True]
             elif offset_available:
                 # truncate to forecast up until some len(df) + offset (which is <= 0)
@@ -139,12 +140,12 @@ def transform_timeseries(
         log.info(f'Using {nr_procs} processes to reshape.')
         pool = mp.Pool(processes=nr_procs)
         # Make type `object` so that dataframe cells can be python lists
-        df_arr = pool.map(partial(_ts_to_obj, historical_columns=ob_arr + tss.historical_columns), df_arr)
+        df_arr = pool.map(partial(_ts_to_obj, historical_columns=[oby] + tss.historical_columns), df_arr)
         df_arr = pool.map(partial(_ts_order_col_to_cell_lists,
-                          order_cols=ob_arr + tss.historical_columns), df_arr)
+                          order_cols=[oby] + tss.historical_columns), df_arr)
         df_arr = pool.map(
             partial(
-                _ts_add_previous_rows, order_cols=ob_arr + tss.historical_columns, window=window),
+                _ts_add_previous_rows, order_cols=[oby] + tss.historical_columns, window=window),
             df_arr)
 
         df_arr = pool.map(partial(_ts_add_future_target, target=target, horizon=tss.horizon,
@@ -159,10 +160,10 @@ def transform_timeseries(
         pool.join()
     else:
         for i in range(n_groups):
-            df_arr[i] = _ts_to_obj(df_arr[i], historical_columns=ob_arr + tss.historical_columns)
-            df_arr[i] = _ts_order_col_to_cell_lists(df_arr[i], order_cols=ob_arr + tss.historical_columns)
+            df_arr[i] = _ts_to_obj(df_arr[i], historical_columns=[oby] + tss.historical_columns)
+            df_arr[i] = _ts_order_col_to_cell_lists(df_arr[i], order_cols=[oby] + tss.historical_columns)
             df_arr[i] = _ts_add_previous_rows(df_arr[i],
-                                              order_cols=ob_arr + tss.historical_columns, window=window)
+                                              order_cols=[oby] + tss.historical_columns, window=window)
             df_arr[i] = _ts_add_future_target(df_arr[i], target=target, horizon=tss.horizon,
                                               data_dtype=tss.target_type, mode=mode)
             if tss.use_previous_target:
@@ -266,10 +267,10 @@ def _ts_to_obj(df: pd.DataFrame, historical_columns: list) -> pd.DataFrame:
 
 def _ts_order_col_to_cell_lists(df: pd.DataFrame, order_cols: list) -> pd.DataFrame:
     """
-    Casts all data in `order_by` columns into cells.
+    Casts all data in the `order_by` column into cells.
 
     :param df: Input dataframe
-    :param order_cols: `order_by` columns
+    :param order_cols: `order_by` column and other columns flagged as `historical`.
 
     :return: Dataframe with all `order_cols` modified so that their values are cells, e.g. `1` -> `[1]`
     """
@@ -282,10 +283,10 @@ def _ts_order_col_to_cell_lists(df: pd.DataFrame, order_cols: list) -> pd.DataFr
 
 def _ts_add_previous_rows(df: pd.DataFrame, order_cols: list, window: int) -> pd.DataFrame:
     """
-    Adds previous rows (as determined by `TimeseriesSettings.window`) into the cells of all `order_by` columns.
+    Adds previous rows (as determined by `TimeseriesSettings.window`) into the cells of the `order_by` column.
 
     :param df: Input dataframe.
-    :param order_cols: `order_by` columns.
+    :param order_cols: `order_by` column and other columns flagged as `historical`.
     :param window: value of `TimeseriesSettings.window` parameter.
     
     :return: Dataframe with all `order_cols` modified so that their values are now arrays of historical context.
