@@ -3,7 +3,8 @@ from lightwood.helpers.device import is_cuda_compatible, get_devices
 from lightwood.helpers.general import mase, is_none, evaluate_accuracy, evaluate_num_array_accuracy,\
     evaluate_array_accuracy, evaluate_multilabel_accuracy, evaluate_regression_accuracy, evaluate_cat_array_accuracy, \
     bounded_evaluate_array_accuracy
-from lightwood.helpers.ts import get_group_matches, get_ts_groups, get_inferred_timestamps, add_tn_conf_bounds
+from lightwood.helpers.ts import get_group_matches, get_ts_groups, get_inferred_timestamps, add_tn_num_conf_bounds, \
+    add_tn_cat_conf_bounds
 from lightwood.helpers.io import read_from_path_or_url
 from lightwood.helpers.parallelism import get_nr_procs, mut_method_call, run_mut_method
 from lightwood.helpers.numeric import is_nan_numeric, filter_nan_and_none
@@ -20,6 +21,6 @@ __all__ = ['to_binary', 'f1_score', 'recall_score', 'precision_score', 'r2_score
            'evaluate_multilabel_accuracy', 'evaluate_regression_accuracy', 'read_from_path_or_url', 'get_nr_procs',
            'mut_method_call', 'run_mut_method', 'tokenize_text', 'analyze_sentences', 'decontracted', 'contains_alnum',
            'get_identifier_description', 'get_identifier_description_mp', 'get_pct_auto_increment',
-           'extract_digits', 'isascii', 'get_inferred_timestamps', 'add_tn_conf_bounds',
+           'extract_digits', 'isascii', 'get_inferred_timestamps', 'add_tn_num_conf_bounds', 'add_tn_cat_conf_bounds',
            'hashtext', 'splitRecursive', 'cast_string_to_python_type', 'gen_chars', 'clean_float', 'word_tokenize',
            'get_language_dist', 'average_vectors', 'concat_vectors_and_pad', 'LightwoodAutocast', 'is_nan_numeric', 'filter_nan_and_none', 'seed']  # noqa
