@@ -1,9 +1,11 @@
 from lightwood.mixer.unit import Unit
 from lightwood.mixer.base import BaseMixer
 from lightwood.mixer.neural import Neural
+from lightwood.mixer.neural_ts import NeuralTs
 from lightwood.mixer.lightgbm import LightGBM
 from lightwood.mixer.lightgbm_array import LightGBMArray
 from lightwood.mixer.sktime import SkTime
+from lightwood.mixer.nhits import NHitsMixer
 from lightwood.mixer.prophet import ProphetMixer
 from lightwood.mixer.regression import Regression
 
@@ -12,5 +14,5 @@ try:
 except Exception:
     QClassic = None
 
-__all__ = ['BaseMixer', 'Neural', 'LightGBM', 'LightGBMArray', 'Unit', 'Regression',
-           'SkTime', 'QClassic', 'ProphetMixer']
+__all__ = ['BaseMixer', 'Neural', 'NeuralTs', 'LightGBM', 'LightGBMArray', 'Unit', 'Regression',
+           'SkTime', 'QClassic', 'ProphetMixer', 'NHitsMixer']
