@@ -31,6 +31,7 @@ class LightGBMArray(BaseMixer):
             fit_on_dev: bool,
             target_encoder: BaseEncoder,
             ts_analysis: Dict[str, object],
+            use_stl: bool,
             tss: TimeseriesSettings
     ):
         super().__init__(stop_after)
@@ -39,8 +40,8 @@ class LightGBMArray(BaseMixer):
         self.submodel_stop_after = stop_after / self.horizon
         self.target = target
         self.offset_pred_cols = [f'{self.target}_timestep_{i}' for i in range(1, self.horizon)]
-        if set(input_cols) != set(self.tss.order_by):
-            input_cols.remove(*self.tss.order_by)
+        if set(input_cols) != {self.tss.order_by}:
+            input_cols.remove(self.tss.order_by)
         for col in self.offset_pred_cols:
             dtype_dict[col] = dtype_dict[self.target]
         self.models = [LightGBM(self.submodel_stop_after,
