@@ -13,10 +13,10 @@ class ProphetMixer(SkTime):
                  model_path: str = 'fbprophet.Prophet',
                  auto_size: bool = True,
                  hyperparam_search: bool = False,
-                 target_transforms: Dict[str, Union[int, str]] = {}
+                 use_decomposers: Dict[str, Union[int, str]] = {}
                  ):
         super().__init__(stop_after, target, dtype_dict, horizon, ts_analysis,
-                         model_path, auto_size, hyperparam_search, target_transforms)
+                         model_path, auto_size, hyperparam_search, use_decomposers)
         self.stable = False
         self.model_path = model_path
         self.possible_models = [self.model_path]
