@@ -71,7 +71,7 @@ class TestTimeseries(unittest.TestCase):
                                                                         'allow_incomplete_history': True,
                                                                         'group_by': ['Country'],
                                                                         'horizon': horizon,
-                                                                        'order_by': [order_by],
+                                                                        'order_by': order_by,
                                                                         'period_intervals': (('daily', 7),),
                                                                         'window': window
                                                                     }}))
@@ -139,7 +139,7 @@ class TestTimeseries(unittest.TestCase):
                                                                         'use_previous_target': False,
                                                                         'allow_incomplete_history': False,
                                                                         'horizon': horizon,
-                                                                        'order_by': [order_by],
+                                                                        'order_by': order_by,
                                                                         'window': window}
                                                                     }))
             jai.model['args']['submodels'] = [jai.model['args']['submodels'][0]]
@@ -196,7 +196,7 @@ class TestTimeseries(unittest.TestCase):
                                                                         'time_aim': 80,
                                                                         'anomaly_detection': False,
                                                                         'timeseries_settings': {
-                                                                            'order_by': ['T'],
+                                                                            'order_by': 'T',
                                                                             'use_previous_target': True,
                                                                             'window': 5
                                                                         },
@@ -219,7 +219,7 @@ class TestTimeseries(unittest.TestCase):
                                                                         'time_aim': 80,
                                                                         'anomaly_detection': False,
                                                                         'timeseries_settings': {
-                                                                            'order_by': ['T'],
+                                                                            'order_by': 'T',
                                                                             'use_previous_target': True,
                                                                             'window': 5,
                                                                             'horizon': 2
@@ -247,7 +247,7 @@ class TestTimeseries(unittest.TestCase):
                                                                         'time_aim': 80,
                                                                         'anomaly_detection': False,
                                                                         'timeseries_settings': {
-                                                                            'order_by': ['T'],
+                                                                            'order_by': 'T',
                                                                             'use_previous_target': True,
                                                                             'window': 5,
                                                                             'horizon': 2
@@ -273,7 +273,7 @@ class TestTimeseries(unittest.TestCase):
         tsteps = 100
         target = 'Value'
         horizon = 20
-        t = np.linspace(0, 1, tsteps, endpoint=False)
+        t = np.linspace(0, 100, tsteps, endpoint=False)
         ts = [i + f for i, f in enumerate(signal.sawtooth(2 * np.pi * 5 * t, width=0.5))]
         df = pd.DataFrame(columns=['Time', target])
         df['Time'] = t
@@ -286,7 +286,7 @@ class TestTimeseries(unittest.TestCase):
         pdef = ProblemDefinition.from_dict({'target': target,
                                             'time_aim': 200,
                                             'timeseries_settings': {
-                                                'order_by': ['Time'],
+                                                'order_by': 'Time',
                                                 'window': 5,
                                                 'horizon': horizon,
                                                 'historical_columns': [f'{target}_2x']
@@ -362,7 +362,7 @@ class TestTimeseries(unittest.TestCase):
         horizon = 20
         # added random noise for irregular sampling
         np.random.seed(0)
-        t = np.linspace(0, 1, tsteps, endpoint=False) + np.random.uniform(size=(tsteps,), low=-0.005, high=0.005)
+        t = np.linspace(0, 100, tsteps, endpoint=False) + np.random.uniform(size=(tsteps,), low=-0.005, high=0.005)
         ts = [i + f for i, f in enumerate(signal.sawtooth(2 * np.pi * 5 * t, width=0.5))]
         df = pd.DataFrame(columns=['Time', target])
         df['Time'] = t
@@ -375,7 +375,7 @@ class TestTimeseries(unittest.TestCase):
         pdef = ProblemDefinition.from_dict({'target': target,
                                             'time_aim': 200,
                                             'timeseries_settings': {
-                                                'order_by': ['Time'],
+                                                'order_by': 'Time',
                                                 'window': 5,
                                                 'horizon': horizon,
                                                 'historical_columns': [f'{target}_2x']
@@ -398,12 +398,7 @@ class TestTimeseries(unittest.TestCase):
         order_by = 'saledate'
         window = 8
         horizon = 4
-        train, _, test = stratify(data,
-                                  pct_train=0.8,
-                                  pct_dev=0,
-                                  pct_test=0.2,
-                                  stratify_on=gby,
-                                  seed=1,
+        train, _, test = stratify(data, pct_train=0.8, pct_dev=0, pct_test=0.2, stratify_on=gby, seed=1,
                                   reshuffle=False)
         jai = json_ai_from_problem(train,
                                    ProblemDefinition.from_dict({'target': target,
@@ -411,7 +406,7 @@ class TestTimeseries(unittest.TestCase):
                                                                 'timeseries_settings': {
                                                                     'group_by': gby,
                                                                     'horizon': horizon,
-                                                                    'order_by': [order_by],
+                                                                    'order_by': order_by,
                                                                     'window': window
                                                                 }}))
         code = code_from_json_ai(jai)
